aboutsummaryrefslogtreecommitdiff
path: root/src/txorphanage.h
diff options
context:
space:
mode:
authorglozow <gloriajzhao@gmail.com>2024-05-10 12:04:50 +0100
committerglozow <gloriajzhao@gmail.com>2024-05-14 10:32:28 +0100
commitc31f148166f01a9167d82501a77823785d28a841 (patch)
treeb1b87ab54e666c9044250230e0f1528981130f34 /src/txorphanage.h
parentefcc5930175f31b685adb4627a038d9f0848eb1f (diff)
downloadbitcoin-c31f148166f01a9167d82501a77823785d28a841.tar.xz
[refactor] TxOrphanage::EraseTx by wtxid
No behavior change right now, as transactions in the orphanage are unique by txid. This makes the next commit easier to review.
Diffstat (limited to 'src/txorphanage.h')
-rw-r--r--src/txorphanage.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/txorphanage.h b/src/txorphanage.h
index 33e41ff5b7..a549fc7f9b 100644
--- a/src/txorphanage.h
+++ b/src/txorphanage.h
@@ -33,8 +33,8 @@ public:
*/
CTransactionRef GetTxToReconsider(NodeId peer) EXCLUSIVE_LOCKS_REQUIRED(!m_mutex);
- /** Erase an orphan by txid */
- int EraseTx(const Txid& txid) EXCLUSIVE_LOCKS_REQUIRED(!m_mutex);
+ /** Erase an orphan by wtxid */
+ int EraseTx(const Wtxid& wtxid) EXCLUSIVE_LOCKS_REQUIRED(!m_mutex);
/** Erase all orphans announced by a peer (eg, after that peer disconnects) */
void EraseForPeer(NodeId peer) EXCLUSIVE_LOCKS_REQUIRED(!m_mutex);
@@ -106,8 +106,8 @@ protected:
* transactions using their witness ids. */
std::map<Wtxid, OrphanMap::iterator> m_wtxid_to_orphan_it GUARDED_BY(m_mutex);
- /** Erase an orphan by txid */
- int EraseTxNoLock(const Txid& txid) EXCLUSIVE_LOCKS_REQUIRED(m_mutex);
+ /** Erase an orphan by wtxid */
+ int EraseTxNoLock(const Wtxid& wtxid) EXCLUSIVE_LOCKS_REQUIRED(m_mutex);
};
#endif // BITCOIN_TXORPHANAGE_H